﻿@config-init @feature:1040 @adoSpecific
Feature: Initialize SpecSync for Azure DevOps config

Rule: A basic configuration can be initialized for Azure DevOps

@tc:1041
Scenario: A basic configuration is initialized for Azure DevOps
	Given there is an Azure DevOps project
	When SpecSync init is executed with answers successfully:
		| question                                              | answer               | optional |
		| Azure DevOps project URL                              | [remote-project-url] | false    |
		| Do you want to check connection?                      | yes                  | false    |
		| Azure DevOps personal access token (PAT) or user name | [remote-user-name]   | false    |
		| Password for user '[remote-user-name]'                | [remote-password]    | true     |
		| Is this ok?                                           | yes                  | false    |
	Then the configuration file should be updated with at least
		| setting           | value                |
		| remote/projectUrl | [remote-project-url] |

@tc:1042
@bypass-integration
Scenario: Authenticating with PAT
	Given there is an Azure DevOps project
	When SpecSync init is executed with answers successfully:
		| question                                              | answer               |
		| Azure DevOps project URL                              | [remote-project-url] |
		| Do you want to check connection?                      | yes                  |
		| Azure DevOps personal access token (PAT) or user name | [remote-pat]         |
	Then the configuration file should be updated with at least
		| setting           | value                |
		| remote/projectUrl | [remote-project-url] |

@tc:1043
@bypass-integration
Scenario Outline: Authenticating with credentials from user-specific config file
	Given there is an Azure DevOps project
	And there is a user-specific config file with the following content:
		"""
		{
			"knownRemotes": [
				{
					"projectUrl": "[remote-project-url]",
					"user": "<user name>"
				}
			]
		}
		"""
	When SpecSync init is executed with answers successfully:
		| question                         | answer               | optional |
		| Azure DevOps project URL         | [remote-project-url] | false    |
		| Do you want to check connection? | yes                  | false    |
		| Password for user '<user name>'  | [remote-password]    | true     |
	Then the configuration file should be updated with at least
		| setting           | value                |
		| remote/projectUrl | [remote-project-url] |
Examples:
	| description   | user name          |
	| Use PAT       | [remote-pat]       |
	| Use User Name | [remote-user-name] |

Rule: The credentials should be offered to save to the user-specific config file

@tc:1044
@bypass-integration
Scenario: Offers saving credentials to user-specific config file
	Given there is a remote server project
	When SpecSync init is executed with answers successfully:
		| question                                              | answer               |
		| Azure DevOps project URL                              | [remote-project-url] |
		| Do you want to check connection?                      | yes                  |
		| Azure DevOps personal access token (PAT) or user name | [remote-pat]         |
		| Do you want to save the PAT to the user-config file   | yes                  |
	Then the configuration file should be updated with at least
		| setting           | value                |
		| remote/projectUrl | [remote-project-url] |
	And the user-specific configuration file should be updated with
		| setting                   | value                |
		| knownRemotes[]/projectUrl | [remote-project-url] |
		| knownRemotes[^1]/user     | [remote-pat]         |

Rule: Cancelled when the connection check fails

@tc:1046
@bypass-integration
Scenario: Wrong credentials provided
	Given there is a remote server project
	When SpecSync init is executed with answers:
		| question                                              | answer               | optional |
		| Azure DevOps project URL                              | [remote-project-url] | false    |
		| Azure DevOps personal access token (PAT) or user name | wrong-user           | false    |
		| Password for user 'wrong-user'                        | wrong-password       | true     |
	Then the command should finish with errors
	And the configuration file should not change

Rule: There are useful defaults for the questions

@tc:1047
@bypass-integration
Scenario: Using default answers for the questions
	Given there is an Azure DevOps project
	When SpecSync init is executed with answers successfully:
		| question                                              | answer               | optional |
		| Azure DevOps project URL                              | [remote-project-url] | false    |
		| Azure DevOps personal access token (PAT) or user name | [remote-user-name]   | false    |
		| Password for user '[remote-user-name]'                | [remote-password]    | true     |
	Then the configuration file should be updated with
		| setting           | value                |
		| remote/projectUrl | [remote-project-url] |
		| configurationKey  | [any]                |
		| remote/scope/type | managedQuery         |

@bypass-integration
Rule: Setup remote scope

Background:
	Given there is an Azure DevOps project

@tc:1397
Scenario: Sets up a TestSuite remote scope
	When SpecSync init is executed with answers successfully:
		| question                                              | answer                                    | optional |
		| Azure DevOps project URL                              | [remote-project-url]                      | false    |
		| Azure DevOps personal access token (PAT) or user name | [remote-user-name]                        | false    |
		| Password for user '[remote-user-name]'                | [remote-password]                         | true     |
		| Do you want to setup a remote scope?                  | Yes, configure a 'testSuite' remote scope | false    |
		| The name of the Test Plan for the suite               | My Plan                                   | false    |
		| The path of the suite within the plan                 | My Suite                                  | false    |
	Then the configuration file should be updated with at least
		| setting                         | value                |
		| remote/projectUrl               | [remote-project-url] |
		| remote/scope/type               | testSuite            |
		| remote/scope/testSuite/path     | My Suite             |
		| remote/scope/testSuite/testPlan | My Plan              |

@tc:1398
Scenario: Sets up a ManagedQuery remote scope
	When SpecSync init is executed with answers successfully:
		| question                                                                                | answer                                       | optional |
		| Azure DevOps project URL                                                                | [remote-project-url]                         | false    |
		| Azure DevOps personal access token (PAT) or user name                                   | [remote-user-name]                           | false    |
		| Password for user '[remote-user-name]'                                                  | [remote-password]                            | true     |
		| Do you want to setup a remote scope?                                                    | Yes, configure a 'managedQuery' remote scope | false    |
		| Please specify a key that identifies this configuration within the Azure DevOps project | MyConfig01                                   | false    |
	Then the configuration file should be updated with
		| setting           | value                |
		| remote/projectUrl | [remote-project-url] |
		| remote/scope/type | managedQuery         |
		| configurationKey  | MyConfig01           |

@tc:1448
Scenario: Sets up a Tag remote scope
	When SpecSync init is executed with answers successfully:
		| question                                                                                | answer                              | optional |
		| Azure DevOps project URL                                                                | [remote-project-url]                | false    |
		| Azure DevOps personal access token (PAT) or user name                                   | [remote-user-name]                  | false    |
		| Password for user '[remote-user-name]'                                                  | [remote-password]                   | true     |
		| Do you want to setup a remote scope?                                                    | Yes, configure a 'tag' remote scope | false    |
		| Please specify a key that identifies this configuration within the Azure DevOps project | MyConfig01                          | false    |
	Then the configuration file should be updated with at least
		| setting           | value                |
		| remote/projectUrl | [remote-project-url] |
		| remote/scope/type | tag                  |
		| configurationKey  | MyConfig01           |

