﻿@hierarchies @adoSpecific @bypass-integration
Feature: Levels based Test Case hierarchy in Azure DevOps

Rule: The Test Suite hierarchy can be created based on tag patterns on different levels

@tc:1433
Scenario: A two-level hierarchy is initialized based on tags
	Given there is an Azure DevOps project
	And there are scenarios in the local repository as
		| scenario | tags                                      |
		| S1       | @area:Pricing, @category:Smoke            |
		| S2       | @area:Pricing, @category:Regression       |
		| S3       | @area:Authorization, @category:Smoke      |
		| S4       | @area:Authorization, @category:Regression |
	And the synchronizer is configured as
		| setting                            | value       |
		| hierarchies[0]/type                | levels      |
		| hierarchies[0]/levels[0]/condition | @area:*     |
		| hierarchies[0]/levels[0]/name      | {1}         |
		| hierarchies[0]/levels[1]/condition | @category:* |
		| hierarchies[0]/levels[1]/name      | Cat_{1}     |
	When the local repository is synchronized with push
	Then the Test Suites should be created and contain the Test Cases as
		| test suite path              | test cases   |
		| Pricing/Cat_Smoke            | Scenario: S1 |
		| Pricing/Cat_Regression       | Scenario: S2 |
		| Authorization/Cat_Smoke      | Scenario: S3 |
		| Authorization/Cat_Regression | Scenario: S4 |

@tc:1434
Scenario: The name setting matches to tag wildcard by default
	Given there is an Azure DevOps project
	And there are scenarios in the local repository as
		| scenario | tags                |
		| S1       | @area:Pricing       |
		| S2       | @area:Authorization |
	And the synchronizer is configured as
		| setting                            | value   |
		| hierarchies[0]/type                | levels  |
		| hierarchies[0]/levels[0]/condition | @area:* |
	When the local repository is synchronized with push
	Then the Test Suites should be created and contain the Test Cases as
		| test suite path | test cases   |
		| Pricing         | Scenario: S1 |
		| Authorization   | Scenario: S2 |

@tc:1435
Scenario: A switch is used to define the level
	The switch construct is the same as being used for field updates

	Given there is an Azure DevOps project
	And there are scenarios in the local repository as
		| scenario | tags           |
		| S1       | @pricing       |
		| S2       | @authorization |
	And the synchronizer is configured as
		| setting                                                 | value         |
		| hierarchies[0]/type                                     | levels        |
		| hierarchies[0]/levels[0]/conditionalName/@pricing       | Pricing       |
		| hierarchies[0]/levels[0]/conditionalName/@authorization | Authorization |
	When the local repository is synchronized with push
	Then the Test Suites should be created and contain the Test Cases as
		| test suite path | test cases   |
		| Pricing         | Scenario: S1 |
		| Authorization   | Scenario: S2 |


@tc:1436
Scenario: The level name can contain suite path
	Given there is an Azure DevOps project
	And there are scenarios in the local repository as
		| scenario | tags                        |
		| S1       | @suite:Pricing/Cat_Smoke    |
		| S2       | @suite:"A/C"/Cat_Regression |
	And the synchronizer is configured as
		| setting                            | value    |
		| hierarchies[0]/type                | levels   |
		| hierarchies[0]/levels[0]/condition | @suite:* |
		| hierarchies[0]/levels[0]/name      | {1}      |
	When the local repository is synchronized with push
	Then the Test Suites should be created and contain the Test Cases as
		| test suite path      | test cases   | description                        |
		| Pricing/Cat_Smoke    | Scenario: S1 | tag contains suite path            |
		| "A/C"/Cat_Regression | Scenario: S2 | suite name contains path separator |


Rule: The non-matching sceanrios can be handled as ignore, skip level, include to parent or include to custom suite

Default: ignore for top level, skipLevel for others

@tc:1437
Scenario: The project contains scenarios that do not match the level conditions
	Given there is an Azure DevOps project
	And there are scenarios in the local repository as
		| scenario | tags                                                                |
		| S1       | @area:Pricing, @component:FrontEnd, @category:Smoke, @priority:High |
		| S2       |                                                                     |
		| S3       | @area:Pricing, @category:Regression, @priority:High                 |
		| S4       | @area:Pricing, @component:FrontEnd                                  |
		| S5       | @area:Pricing, @component:FrontEnd, @priority:High                  |
		| S6       | @area:Pricing, @component:FrontEnd, @category:Smoke                 |
	And the synchronizer is configured as
		| setting                                     | value           |
		| hierarchies[0]/type                         | levels          |
		| hierarchies[0]/levels[0]/condition          | @area:*         |
		| hierarchies[0]/levels[0]/name               | {1}             |
		| hierarchies[0]/levels[0]/onNotMatching      | ignore          |
		| hierarchies[0]/levels[1]/condition          | @component:*    |
		| hierarchies[0]/levels[1]/name               | {1}             |
		| hierarchies[0]/levels[1]/onNotMatching      | skipLevel       |
		| hierarchies[0]/levels[2]/condition          | @category:*     |
		| hierarchies[0]/levels[2]/name               | {1}             |
		| hierarchies[0]/levels[2]/onNotMatching      | includeToParent |
		| hierarchies[0]/levels[3]/condition          | @priority:*     |
		| hierarchies[0]/levels[3]/name               | Priority_{1}    |
		| hierarchies[0]/levels[3]/onNotMatching      | customName      |
		| hierarchies[0]/levels[3]/nameForNotMatching | Priority_Normal |
	When the local repository is synchronized with push
	Then the Test Suites should be created and contain the Test Cases as
		| test suite path                        | test cases                 | description                                           |
		| Pricing/FrontEnd/Smoke/Priority_High   | Scenario: S1               | all levels specified                                  |
		| /                                      |                            | S2 was not included to a suite                        |
		| Pricing/Regression/Priority_High       | Scenario: S3               | one with 'skipLevel' missing, everything else sepcied |
		| Pricing/FrontEnd                       | Scenario: S4, Scenario: S5 | one with 'includeToParent' missing                    |
		| Pricing/FrontEnd/Smoke/Priority_Normal | Scenario: S6               | one with 'customName' missing                         |

@tc:1438
Scenario: Using default settings for onNotMatching
	ignore for top level, skipLevel for others
	Given there is an Azure DevOps project
	And there are scenarios in the local repository as
		| scenario | tags                                               |
		| S1       | @area:Pricing, @component:FrontEnd, @priority:High |
		| S2       |                                                    |
		| S3       | @area:Pricing, @priority:High                      |
		| S4       | @area:Pricing                                      |
	And the synchronizer is configured as
		| setting                            | value        |
		| hierarchies[0]/type                | levels       |
		| hierarchies[0]/levels[0]/condition | @area:*      |
		| hierarchies[0]/levels[0]/name      | {1}          |
		| hierarchies[0]/levels[1]/condition | @component:* |
		| hierarchies[0]/levels[1]/name      | {1}          |
		| hierarchies[0]/levels[2]/condition | @priority:*  |
		| hierarchies[0]/levels[2]/name      | Priority_{1} |
	When the local repository is synchronized with push
	Then the Test Suites should be created and contain the Test Cases as
		| test suite path                | test cases   | description                                    |
		| Pricing/FrontEnd/Priority_High | Scenario: S1 | all levels specified                           |
		| /                              |              | S2 was not included to a suite                 |
		| Pricing/Priority_High          | Scenario: S3 | non-top level missing, everything else sepcied |
		| Pricing                        | Scenario: S4 | non-top levels missing                         |

