﻿@remoteScope
Feature: Remote Scope

Remote scope specifies the set of remote server Test Cases that are 
synchronized with the current configuration.

Specifying remote scope is optional, but allows features that require this 
information, like:

* detection of deleted local test cases (was in remote scope, but not found locally)
* pulling new Test Cases (to decide what Test Cases to pull)


Rule: Should detect Test Case deletion during full synchronization

Only when full synchronization: in case there is a filter applied 
(e.g. --tagFilter), the Test Cases should not be removed.


@tc:263
Scenario: The Test Case of a deleted scenario is marked
	The specsync:removed-from:* tag is added only if configuration key is set

	Given there is an Azure DevOps project
	And the configuration key is set to "my-project-01"
	And a remote scope is configured
	And there is an existing synchronized feature file
		"""
		Feature: My Feature

		@tc:[id-of-test-case]
		Scenario: Scenario 1
			When I do something
		"""
	When the feature file is updated to:
		"""
		Feature: My Feature

		# Scenario 1 deleted
		"""
	And the local repository is synchronized with push
	Then the Test Case should contain the following tags: "specsync:removed, specsync:removed-from:my-project-01"

@tc:971
@bypass-integration
Scenario: In case of filtered synchronization the Test Case of a deleted scenario is not removed
	Unless toolSettings/forceProcessingRemovalsOnFilter is set to true

	Given there is an Azure DevOps project
	And a remote scope is configured
	And there is an existing synchronized feature file
		"""
		Feature: My Feature

		@tc:[id-of-test-case]
		Scenario: Scenario 1
			When I do something
		"""
	And the synchronizer is provided with an option to filter scenarios with "@some-filter"
	When the feature file is updated to:
		"""
		Feature: My Feature

		# Scenario 1 deleted
		"""
	And the local repository is synchronized with push
	Then the Test Case should not contain the following tags: "specsync:removed"


Rule: Should handle re-inclusion of a deleted Test Case

@tc:264
Scenario: The removed tag is removed from the Test Case once it is reconnected
	Given there is an Azure DevOps project
	And a remote scope is configured
	And there is an existing synchronized scenario
		"""
		@tc:[id-of-test-case]
		@sometag
		Scenario: Scenario 1
			When I do something
		"""
	And the scenario has been updated and synchronized as:
		"""
		# Scenario 1 deleted
		"""
	When the scenario is updated to:
		"""
		# Scenario 1 restored
		@tc:[id-of-test-case]
		@sometag
		Scenario: Scenario 1
			When I do something
		"""
	And the local repository is synchronized with push
	Then the Test Case should have the following tags: "sometag"
	And the remote scope should contain the following Test Cases
		| test case            |
		| Scenario: Scenario 1 |

Rule: Scope changes should be reflected in the remote scope, while filter changes should not

Filtering is a way to temporarily synchronize only a subset of the scenarios, 
but the remote scope keeps containing all scenarios, even if they are currently 
filtered out.

@tc:265
@bypass-integration @adoSpecific
Scenario: Out-of-scope scenarios are removed from remote scope
	Given there is an Azure DevOps project with an empty Test Suite 'RemoteScopeSuite'
	And the synchronizer is configured as
		| setting                     | value            |
		| remote/scope/type           | testSuite        |
		| remote/scope/testSuite/name | RemoteScopeSuite |
	And there is an existing synchronized scenario
		"""
		@tc:[id-of-test-case]
		@not_done
		Scenario: Scenario 1
			When I do something
		"""
	And the synchronizer is configured to scope scenarios tagged with "@done"
	When the local repository is synchronized with push
	Then the Test Suite "RemoteScopeSuite" should be empty


@tc:266
@bypass-integration
Scenario: Filtered out scenarios are not removed from remote scope
	Given there is an Azure DevOps project
	And a remote scope is configured
	And there is an existing synchronized scenario
		"""
		@tc:[id-of-test-case]
		@done @not_interesting_now 
		Scenario: Scenario 1
			When I do something
		"""
	And the synchronizer is provided with an option to filter scenarios with "@interesting"
	And the synchronizer is configured to scope scenarios tagged with "@done"
	When the local repository is synchronized with push
	Then the remote scope should contain the following Test Cases
		| test case            |
		| Scenario: Scenario 1 |
